@@ -6,27 +6,27 @@
 
 #include "device.h"
 
-#include <QVector>
 #include <QSet>
 #include <QSslCertificate>
 #include <QSslKey>
+#include <QVector>
 
-#include <KSharedConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KSharedConfig>
 
-#include "core_debug.h"
-#include "kdeconnectplugin.h"
-#include "pluginloader.h"
 #include "backends/devicelink.h"
 #include "backends/lan/landevicelink.h"
 #include "backends/linkprovider.h"
-#include "networkpacket.h"
-#include "kdeconnectconfig.h"
+#include "core_debug.h"
 #include "daemon.h"
 #include "dbushelper.h"
+#include "kdeconnectconfig.h"
+#include "kdeconnectplugin.h"
+#include "networkpacket.h"
+#include "pluginloader.h"
 
-//In older Qt released, qAsConst isnt available
+// In older Qt released, qAsConst isnt available
 #include "qtcompat_p.h"
 
 class Device::DevicePrivate
@@ -35,7 +35,6 @@ public:
     DevicePrivate(const QString &id)
         : m_deviceId(id)
     {
-
     }
 
     ~DevicePrivate()
@@ -58,12 +57,12 @@ public:
     QSet<PairingHandler *> m_pairRequests;
 };
 
-static void warn(const QString& info)
+static void warn(const QString &info)
 {
     qWarning() << "Device pairing error" << info;
 }
 
-Device::Device(QObject* parent, const QString& id)
+Device::Device(QObject *parent, const QString &id)
     : QObject(parent)
     , d(new Device::DevicePrivate(id))
 {
@@ -73,17 +72,17 @@ Device::Device(QObject* parent, const QString& id)
     d->m_deviceName = info.deviceName;
     d->m_deviceType = str2type(info.deviceType);
 
-    //Register in bus
+    // Register in bus
     QDBusConnection::sessionBus().registerObject(dbusPath(), this, QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
 
-    //Assume every plugin is supported until addLink is called and we can get the actual list
+    // Assume every plugin is supported until addLink is called and we can get the actual list
     d->m_allPlugins = PluginLoader::instance()->getPluginList().toSet();
     d->m_supportedPlugins = d->m_allPlugins;
 
     connect(this, &Device::pairingError, this, &warn);
 }
 
-Device::Device(QObject* parent, const NetworkPacket& identityPacket, DeviceLink* dl)
+Device::Device(QObject *parent, const NetworkPacket &identityPacket, DeviceLink *dl)
     : QObject(parent)
     , d(new Device::DevicePrivate(identityPacket.get<QString>(QStringLiteral("deviceId"))))
 {
@@ -92,7 +91,7 @@ Device::Device(QObject* parent, const NetworkPacket& identityPacket, DeviceLink*
 
     addLink(identityPacket, dl);
 
-    //Register in bus
+    // Register in bus
     QDBusConnection::sessionBus().registerObject(dbusPath(), this, QDBusConnection::ExportScriptableContents | QDBusConnection::ExportAdaptors);
 
     connect(this, &Device::pairingError, this, &warn);
@@ -136,7 +135,7 @@ QStringList Device::supportedPlugins() const
     return d->m_supportedPlugins.toList();
 }
 
-bool Device::hasPlugin(const QString& name) const
+bool Device::hasPlugin(const QString &name) const
 {
     return d->m_plugins.contains(name);
 }
@@ -148,28 +147,29 @@ QStringList Device::loadedPlugins() const
 
 void Device::reloadPlugins()
 {
-    QHash<QString, KdeConnectPlugin*> newPluginMap, oldPluginMap = d->m_plugins;
-    QMultiMap<QString, KdeConnectPlugin*> newPluginsByIncomingCapability;
+    QHash<QString, KdeConnectPlugin *> newPluginMap, oldPluginMap = d->m_plugins;
+    QMultiMap<QString, KdeConnectPlugin *> newPluginsByIncomingCapability;
 
-    if (isTrusted() && isReachable()) { //Do not load any plugin for unpaired devices, nor useless loading them for unreachable devices
+    if (isTrusted() && isReachable()) { // Do not load any plugin for unpaired devices, nor useless loading them for unreachable devices
 
-        PluginLoader* loader = PluginLoader::instance();
+        PluginLoader *loader = PluginLoader::instance();
 
-        for (const QString& pluginName : qAsConst(d->m_supportedPlugins)) {
+        for (const QString &pluginName : qAsConst(d->m_supportedPlugins)) {
             const KPluginMetaData service = loader->getPluginInfo(pluginName);
 
             const bool pluginEnabled = isPluginEnabled(pluginName);
-            const QSet<QString> incomingCapabilities = KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPacketType")).toSet();
+            const QSet<QString> incomingCapabilities =
+                KPluginMetaData::readStringList(service.rawData(), QStringLiteral("X-KdeConnect-SupportedPacketType")).toSet();
 
             if (pluginEnabled) {
-                KdeConnectPlugin* plugin = d->m_plugins.take(pluginName);
+                KdeConnectPlugin *plugin = d->m_plugins.take(pluginName);
 
                 if (!plugin) {
                     plugin = loader->instantiatePluginForDevice(pluginName, this);
                 }
                 Q_ASSERT(plugin);
 
-                for (const QString& interface : incomingCapabilities) {
+                for (const QString &interface : incomingCapabilities) {
                     newPluginsByIncomingCapability.insert(interface, plugin);
                 }
 
@@ -180,20 +180,23 @@ void Device::reloadPlugins()
 
     const bool differentPlugins = oldPluginMap != newPluginMap;
 
-    //Erase all left plugins in the original map (meaning that we don't want
-    //them anymore, otherwise they would have been moved to the newPluginMap)
+    // Erase all left plugins in the original map (meaning that we don't want
+    // them anymore, otherwise they would have been moved to the newPluginMap)
     qDeleteAll(d->m_plugins);
     d->m_plugins = newPluginMap;
     d->m_pluginsByIncomingCapability = newPluginsByIncomingCapability;
 
     QDBusConnection bus = QDBusConnection::sessionBus();
-    for (KdeConnectPlugin* plugin : qAsConst(d->m_plugins)) {
-        //TODO: see how it works in Android (only done once, when created)
+    for (KdeConnectPlugin *plugin : qAsConst(d->m_plugins)) {
+        // TODO: see how it works in Android (only done once, when created)
         plugin->connected();
 
         const QString dbusPath = plugin->dbusPath();
         if (!dbusPath.isEmpty()) {
-            bus.registerObject(dbusPath, plugin, QDBusConnection::ExportAllProperties | QDBusConnection::ExportScriptableInvokables | QDBusConnection::ExportScriptableSignals | QDBusConnection::ExportScriptableSlots);
+            bus.registerObject(dbusPath,
+                               plugin,
+                               QDBusConnection::ExportAllProperties | QDBusConnection::ExportScriptableInvokables | QDBusConnection::ExportScriptableSignals
+                                   | QDBusConnection::ExportScriptableSlots);
         }
     }
     if (differentPlugins) {
@@ -218,14 +221,14 @@ void Device::requestPair()
         return;
     }
 
-    for (DeviceLink* dl : qAsConst(d->m_deviceLinks)) {
+    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
         dl->userRequestsPair();
     }
 }
 
 void Device::unpair()
 {
-    for (DeviceLink* dl : qAsConst(d->m_deviceLinks)) {
+    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
         dl->userRequestsUnpair();
     }
     KdeConnectConfig::instance().removeTrustedDevice(id());
@@ -237,7 +240,7 @@ void Device::pairStatusChanged(DeviceLink::PairStatus status)
     if (status == DeviceLink::NotPaired) {
         KdeConnectConfig::instance().removeTrustedDevice(id());
 
-        for (DeviceLink* dl : qAsConst(d->m_deviceLinks)) {
+        for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
             if (dl != sender()) {
                 dl->setPairStatus(DeviceLink::NotPaired);
             }
@@ -246,21 +249,21 @@ void Device::pairStatusChanged(DeviceLink::PairStatus status)
         KdeConnectConfig::instance().addTrustedDevice(id(), name(), type());
     }
 
-    reloadPlugins(); //Will load/unload plugins
+    reloadPlugins(); // Will load/unload plugins
 
     bool isTrusted = (status == DeviceLink::Paired);
     Q_EMIT trustedChanged(isTrusted);
     Q_ASSERT(isTrusted == this->isTrusted());
 }
 
-static bool lessThan(DeviceLink* p1, DeviceLink* p2)
+static bool lessThan(DeviceLink *p1, DeviceLink *p2)
 {
     return p1->provider()->priority() > p2->provider()->priority();
 }
 
-void Device::addLink(const NetworkPacket& identityPacket, DeviceLink* link)
+void Device::addLink(const NetworkPacket &identityPacket, DeviceLink *link)
 {
-    //qCDebug(KDECONNECT_CORE) << "Adding link to" << id() << "via" << link->provider();
+    // qCDebug(KDECONNECT_CORE) << "Adding link to" << id() << "via" << link->provider();
 
     setName(identityPacket.get<QString>(QStringLiteral("deviceName")));
     setType(identityPacket.get<QString>(QStringLiteral("deviceType")));
@@ -271,30 +274,29 @@ void Device::addLink(const NetworkPacket& identityPacket, DeviceLink* link)
 
     d->m_protocolVersion = identityPacket.get<int>(QStringLiteral("protocolVersion"), -1);
     if (d->m_protocolVersion != NetworkPacket::s_protocolVersion) {
-        qCWarning(KDECONNECT_CORE) << d->m_deviceName << "- warning, device uses a different protocol version" << d->m_protocolVersion << "expected" << NetworkPacket::s_protocolVersion;
+        qCWarning(KDECONNECT_CORE) << d->m_deviceName << "- warning, device uses a different protocol version" << d->m_protocolVersion << "expected"
+                                   << NetworkPacket::s_protocolVersion;
     }
 
-    connect(link, &QObject::destroyed,
-            this, &Device::linkDestroyed);
+    connect(link, &QObject::destroyed, this, &Device::linkDestroyed);
 
     d->m_deviceLinks.append(link);
 
-    //Theoretically we will never add two links from the same provider (the provider should destroy
-    //the old one before this is called), so we do not have to worry about destroying old links.
+    // Theoretically we will never add two links from the same provider (the provider should destroy
+    // the old one before this is called), so we do not have to worry about destroying old links.
     //-- Actually, we should not destroy them or the provider will store an invalid ref!
 
-    connect(link, &DeviceLink::receivedPacket,
-            this, &Device::privateReceivedPacket);
+    connect(link, &DeviceLink::receivedPacket, this, &Device::privateReceivedPacket);
 
     std::sort(d->m_deviceLinks.begin(), d->m_deviceLinks.end(), lessThan);
 
     const bool capabilitiesSupported = identityPacket.has(QStringLiteral("incomingCapabilities")) || identityPacket.has(QStringLiteral("outgoingCapabilities"));
     if (capabilitiesSupported) {
-        const QSet<QString> outgoingCapabilities = identityPacket.get<QStringList>(QStringLiteral("outgoingCapabilities")).toSet()
-                          , incomingCapabilities = identityPacket.get<QStringList>(QStringLiteral("incomingCapabilities")).toSet();
+        const QSet<QString> outgoingCapabilities = identityPacket.get<QStringList>(QStringLiteral("outgoingCapabilities")).toSet(),
+                            incomingCapabilities = identityPacket.get<QStringList>(QStringLiteral("incomingCapabilities")).toSet();
 
         d->m_supportedPlugins = PluginLoader::instance()->pluginsForCapabilities(incomingCapabilities, outgoingCapabilities);
-        //qDebug() << "new plugins for" << m_deviceName << m_supportedPlugins << incomingCapabilities << outgoingCapabilities;
+        // qDebug() << "new plugins for" << m_deviceName << m_supportedPlugins << incomingCapabilities << outgoingCapabilities;
     } else {
         d->m_supportedPlugins = PluginLoader::instance()->getPluginList().toSet();
     }
@@ -311,7 +313,7 @@ void Device::addLink(const NetworkPacket& identityPacket, DeviceLink* link)
     connect(link, &DeviceLink::pairingError, this, &Device::pairingError);
 }
 
-void Device::addPairingRequest(PairingHandler* handler)
+void Device::addPairingRequest(PairingHandler *handler)
 {
     const bool wasEmpty = d->m_pairRequests.isEmpty();
     d->m_pairRequests.insert(handler);
@@ -320,7 +322,7 @@ void Device::addPairingRequest(PairingHandler* handler)
         Q_EMIT hasPairingRequestsChanged(!d->m_pairRequests.isEmpty());
 }
 
-void Device::removePairingRequest(PairingHandler* handler)
+void Device::removePairingRequest(PairingHandler *handler)
 {
     const bool wasEmpty = d->m_pairRequests.isEmpty();
     d->m_pairRequests.remove(handler);
@@ -339,9 +341,9 @@ void Device::acceptPairing()
     if (d->m_pairRequests.isEmpty())
         qWarning() << "no pair requests to accept!";
 
-    //copying because the pairing handler will be removed upon accept
+    // copying because the pairing handler will be removed upon accept
     const auto prCopy = d->m_pairRequests;
-    for (auto ph: prCopy)
+    for (auto ph : prCopy)
         ph->acceptPairing();
 }
 
@@ -350,22 +352,22 @@ void Device::rejectPairing()
     if (d->m_pairRequests.isEmpty())
         qWarning() << "no pair requests to reject!";
 
-    //copying because the pairing handler will be removed upon reject
+    // copying because the pairing handler will be removed upon reject
     const auto prCopy = d->m_pairRequests;
-    for (auto ph: prCopy)
+    for (auto ph : prCopy)
         ph->rejectPairing();
 }
 
-void Device::linkDestroyed(QObject* o)
+void Device::linkDestroyed(QObject *o)
 {
-    removeLink(static_cast<DeviceLink*>(o));
+    removeLink(static_cast<DeviceLink *>(o));
 }
 
-void Device::removeLink(DeviceLink* link)
+void Device::removeLink(DeviceLink *link)
 {
     d->m_deviceLinks.removeAll(link);
 
-    //qCDebug(KDECONNECT_CORE) << "RemoveLink" << m_deviceLinks.size() << "links remaining";
+    // qCDebug(KDECONNECT_CORE) << "RemoveLink" << m_deviceLinks.size() << "links remaining";
 
     if (d->m_deviceLinks.isEmpty()) {
         reloadPlugins();
@@ -373,35 +375,35 @@ void Device::removeLink(DeviceLink* link)
     }
 }
 
-bool Device::sendPacket(NetworkPacket& np)
+bool Device::sendPacket(NetworkPacket &np)
 {
     Q_ASSERT(np.type() != PACKET_TYPE_PAIR);
     Q_ASSERT(isTrusted());
 
-    //Maybe we could block here any packet that is not an identity or a pairing packet to prevent sending non encrypted data
-    for (DeviceLink* dl : qAsConst(d->m_deviceLinks)) {
-        if (dl->sendPacket(np)) return true;
+    // Maybe we could block here any packet that is not an identity or a pairing packet to prevent sending non encrypted data
+    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
+        if (dl->sendPacket(np))
+            return true;
     }
 
     return false;
 }
 
-void Device::privateReceivedPacket(const NetworkPacket& np)
+void Device::privateReceivedPacket(const NetworkPacket &np)
 {
     Q_ASSERT(np.type() != PACKET_TYPE_PAIR);
     if (isTrusted()) {
-        const QList<KdeConnectPlugin*> plugins = d->m_pluginsByIncomingCapability.values(np.type());
+        const QList<KdeConnectPlugin *> plugins = d->m_pluginsByIncomingCapability.values(np.type());
         if (plugins.isEmpty()) {
             qWarning() << "discarding unsupported packet" << np.type() << "for" << name();
         }
-        for (KdeConnectPlugin* plugin : plugins) {
+        for (KdeConnectPlugin *plugin : plugins) {
             plugin->receivePacket(np);
         }
     } else {
         qCDebug(KDECONNECT_CORE) << "device" << name() << "not paired, ignoring packet" << np.type();
         unpair();
     }
-
 }
 
 bool Device::isTrusted() const
@@ -413,18 +415,19 @@ QStringList Device::availableLinks() const
 {
     QStringList sl;
     sl.reserve(d->m_deviceLinks.size());
-    for (DeviceLink* dl : qAsConst(d->m_deviceLinks)) {
+    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
         sl.append(dl->provider()->name());
     }
     return sl;
 }
 
-void Device::cleanUnneededLinks() {
+void Device::cleanUnneededLinks()
+{
     if (isTrusted()) {
         return;
     }
-    for(int i = 0; i < d->m_deviceLinks.size(); ) {
-        DeviceLink* dl = d->m_deviceLinks[i];
+    for (int i = 0; i < d->m_deviceLinks.size();) {
+        DeviceLink *dl = d->m_deviceLinks[i];
         if (!dl->linkShouldBeKeptAlive()) {
             dl->deleteLater();
             d->m_deviceLinks.remove(i);
@@ -436,8 +439,8 @@ void Device::cleanUnneededLinks() {
 
 QHostAddress Device::getLocalIpAddress() const
 {
-    for (DeviceLink* dl : qAsConst(d->m_deviceLinks)) {
-        LanDeviceLink* ldl = dynamic_cast<LanDeviceLink*>(dl);
+    for (DeviceLink *dl : qAsConst(d->m_deviceLinks)) {
+        LanDeviceLink *ldl = dynamic_cast<LanDeviceLink *>(dl);
         if (ldl) {
             return ldl->hostAddress();
         }
@@ -445,21 +448,33 @@ QHostAddress Device::getLocalIpAddress() const
     return QHostAddress::Null;
 }
 
-Device::DeviceType Device::str2type(const QString& deviceType) {
-    if (deviceType == QLatin1String("desktop")) return Desktop;
-    if (deviceType == QLatin1String("laptop")) return Laptop;
-    if (deviceType == QLatin1String("smartphone") || deviceType == QLatin1String("phone")) return Phone;
-    if (deviceType == QLatin1String("tablet")) return Tablet;
-    if (deviceType == QLatin1String("tv")) return Tv;
+Device::DeviceType Device::str2type(const QString &deviceType)
+{
+    if (deviceType == QLatin1String("desktop"))
+        return Desktop;
+    if (deviceType == QLatin1String("laptop"))
+        return Laptop;
+    if (deviceType == QLatin1String("smartphone") || deviceType == QLatin1String("phone"))
+        return Phone;
+    if (deviceType == QLatin1String("tablet"))
+        return Tablet;
+    if (deviceType == QLatin1String("tv"))
+        return Tv;
     return Unknown;
 }
 
-QString Device::type2str(Device::DeviceType deviceType) {
-    if (deviceType == Desktop) return QStringLiteral("desktop");
-    if (deviceType == Laptop) return QStringLiteral("laptop");
-    if (deviceType == Phone) return QStringLiteral("smartphone");
-    if (deviceType == Tablet) return QStringLiteral("tablet");
-    if (deviceType == Tv) return QStringLiteral("tv");
+QString Device::type2str(Device::DeviceType deviceType)
+{
+    if (deviceType == Desktop)
+        return QStringLiteral("desktop");
+    if (deviceType == Laptop)
+        return QStringLiteral("laptop");
+    if (deviceType == Phone)
+        return QStringLiteral("smartphone");
+    if (deviceType == Tablet)
+        return QStringLiteral("tablet");
+    if (deviceType == Tv)
+        return QStringLiteral("tv");
     return QStringLiteral("unknown");
 }
 
@@ -470,7 +485,6 @@ QString Device::statusIconName() const
 
 QString Device::iconName() const
 {
-
     return iconForStatus(true, false);
 }
 
@@ -478,18 +492,18 @@ QString Device::iconForStatus(bool reachable, bool trusted) const
 {
     Device::DeviceType deviceType = d->m_deviceType;
     if (deviceType == Device::Unknown) {
-        deviceType = Device::Phone; //Assume phone if we don't know the type
+        deviceType = Device::Phone; // Assume phone if we don't know the type
     } else if (deviceType == Device::Desktop) {
         deviceType = Device::Device::Laptop; // We don't have desktop icon yet
     }
 
-    QString status = (reachable? (trusted? QStringLiteral("connected") : QStringLiteral("disconnected")) : QStringLiteral("trusted"));
+    QString status = (reachable ? (trusted ? QStringLiteral("connected") : QStringLiteral("disconnected")) : QStringLiteral("trusted"));
     QString type = type2str(deviceType);
 
-    return type+status;
+    return type + status;
 }
 
-void Device::setName(const QString& name)
+void Device::setName(const QString &name)
 {
     if (d->m_deviceName != name) {
         d->m_deviceName = name;
@@ -498,7 +512,7 @@ void Device::setName(const QString& name)
     }
 }
 
-void Device::setType(const QString& strtype)
+void Device::setType(const QString &strtype)
 {
     auto type = str2type(strtype);
     if (d->m_deviceType != type) {
@@ -508,12 +522,12 @@ void Device::setType(const QString& strtype)
     }
 }
 
-KdeConnectPlugin* Device::plugin(const QString& pluginName) const
+KdeConnectPlugin *Device::plugin(const QString &pluginName) const
 {
     return d->m_plugins[pluginName];
 }
 
-void Device::setPluginEnabled(const QString& pluginName, bool enabled)
+void Device::setPluginEnabled(const QString &pluginName, bool enabled)
 {
     if (!d->m_allPlugins.contains(pluginName)) {
         return;
@@ -526,7 +540,7 @@ void Device::setPluginEnabled(const QString& pluginName, bool enabled)
     reloadPlugins();
 }
 
-bool Device::isPluginEnabled(const QString& pluginName) const
+bool Device::isPluginEnabled(const QString &pluginName) const
 {
     const QString enabledKey = pluginName + QStringLiteral("Enabled");
     KConfigGroup pluginStates = KSharedConfig::openConfig(pluginsConfigFile())->group("Plugins");
@@ -541,12 +555,12 @@ QString Device::encryptionInfo() const
     const QCryptographicHash::Algorithm digestAlgorithm = QCryptographicHash::Algorithm::Sha256;
 
     QString localChecksum = QString::fromLatin1(KdeConnectConfig::instance().certificate().digest(digestAlgorithm).toHex());
-    for (int i = 2; i<localChecksum.size(); i += 3) {
+    for (int i = 2; i < localChecksum.size(); i += 3) {
         localChecksum.insert(i, QStringLiteral(":")); // Improve readability
     }
     result += i18n("SHA256 fingerprint of your device certificate is: %1\n", localChecksum);
 
-    std::string  remotePem = KdeConnectConfig::instance().getDeviceProperty(id(), QStringLiteral("certificate")).toStdString();
+    std::string remotePem = KdeConnectConfig::instance().getDeviceProperty(id(), QStringLiteral("certificate")).toStdString();
     QSslCertificate remoteCertificate = QSslCertificate(QByteArray(remotePem.c_str(), (int)remotePem.size()));
     QString remoteChecksum = QString::fromLatin1(remoteCertificate.digest(digestAlgorithm).toHex());
     for (int i = 2; i < remoteChecksum.size(); i += 3) {
@@ -579,7 +593,7 @@ QByteArray Device::verificationKey() const
     return hash.result().toHex();
 }
 
-QString Device::pluginIconName(const QString& pluginName)
+QString Device::pluginIconName(const QString &pluginName)
 {
     if (hasPlugin(pluginName)) {
         return d->m_plugins[pluginName]->iconName();
