@@ -8,20 +8,25 @@
 
 #include <KSystemClipboard>
 
-#include <QMimeData>
 #include <QDateTime>
+#include <QMimeData>
 
 QString ClipboardListener::currentContent()
 {
     return m_currentContent;
 }
 
-qint64 ClipboardListener::updateTimestamp(){
+ClipboardListener::ClipboardContentType ClipboardListener::currentContentType()
+{
+    return m_currentContentType;
+}
 
+qint64 ClipboardListener::updateTimestamp()
+{
     return m_updateTimestamp;
 }
 
-ClipboardListener* ClipboardListener::instance()
+ClipboardListener *ClipboardListener::instance()
 {
     static ClipboardListener *me = nullptr;
     if (!me) {
@@ -30,18 +35,21 @@ ClipboardListener* ClipboardListener::instance()
     return me;
 }
 
-void ClipboardListener::refreshContent(const QString& content)
+void ClipboardListener::refreshContent(const QString &content, ClipboardListener::ClipboardContentType contentType)
 {
     m_updateTimestamp = QDateTime::currentDateTime().toMSecsSinceEpoch();
     m_currentContent = content;
+    m_currentContentType = contentType;
 }
 
 ClipboardListener::ClipboardListener()
     : clipboard(KSystemClipboard::instance())
 {
 #ifdef Q_OS_MAC
-    connect(&m_clipboardMonitorTimer, &QTimer::timeout, this, [this](){ updateClipboard(QClipboard::Clipboard); });
-    m_clipboardMonitorTimer.start(1000);    // Refresh 1s
+    connect(&m_clipboardMonitorTimer, &QTimer::timeout, this, [this]() {
+        updateClipboard(QClipboard::Clipboard);
+    });
+    m_clipboardMonitorTimer.start(1000); // Refresh 1s
 #endif
     connect(clipboard, &KSystemClipboard::changed, this, &ClipboardListener::updateClipboard);
 }
@@ -52,17 +60,22 @@ void ClipboardListener::updateClipboard(QClipboard::Mode mode)
         return;
     }
 
+    ClipboardListener::ClipboardContentType contentType = ClipboardListener::ClipboardContentTypeUnknown;
+    if (clipboard->mimeData(mode)->data(QStringLiteral("x-kde-passwordManagerHint")) == QByteArrayLiteral("secret")) {
+        contentType = ClipboardListener::ClipboardContentTypePassword;
+    }
+
     const QString content = clipboard->text(QClipboard::Clipboard);
-    if (content == m_currentContent) {
+    if (content == m_currentContent && contentType == m_currentContentType) {
         return;
     }
-    refreshContent(content);
-    Q_EMIT clipboardChanged(content);
+    refreshContent(content, contentType);
+    Q_EMIT clipboardChanged(content, contentType);
 }
 
-void ClipboardListener::setText(const QString& content)
+void ClipboardListener::setText(const QString &content)
 {
-    refreshContent(content);
+    refreshContent(content, ClipboardListener::ClipboardContentTypeUnknown);
     auto mime = new QMimeData;
     mime->setText(content);
     clipboard->setMimeData(mime, QClipboard::Clipboard);
